Index: sdk/lib/_internal/pub/test/unknown_source_test.dart |
diff --git a/sdk/lib/_internal/pub/test/unknown_source_test.dart b/sdk/lib/_internal/pub/test/unknown_source_test.dart |
index dab714cc0f5a5d98ae8ce20043f22a5af97fac85..d1980834b19c23392ff8c21a1eaa1cd618f37222 100644 |
--- a/sdk/lib/_internal/pub/test/unknown_source_test.dart |
+++ b/sdk/lib/_internal/pub/test/unknown_source_test.dart |
@@ -12,7 +12,7 @@ import 'test_pub.dart'; |
main() { |
initConfig(); |
- forBothPubInstallAndUpdate((command) { |
+ forBothPubGetAndUpgrade((command) { |
integration('fails gracefully on a dependency from an unknown source', () { |
d.appDir({"foo": {"bad": "foo"}}).create(); |
@@ -63,7 +63,7 @@ main() { |
pubCommand(command); |
// Should update to the new one. |
d.dir(packagesPath, [ |
d.dir("foo", [ |
d.file("foo.dart", 'main() => "foo";') |
@@ -63,7 +63,7 @@ main() { |
pubCommand(command); |
- // Should update to the new one. |
+ // Should upgrade to the new one. |
d.dir(packagesPath, [ |
d.dir("foo", [ |